OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Nepoznat tip datoteke",
    "Invalid image" : "Nevažeća datoteka",
    "Files" : "Datoteke",
    "__language_name__" : "Bosanski jezik",
    "Help" : "Pomoć",
    "Apps" : "Aplikacije",
    "Settings" : "Podešavanje",
    "Log out" : "Odjava",
    "Users" : "Korisnici",
    "Email" : "E-pošta",
    "Phone" : "Telefon",
    "Website" : "Web-prezentacija",
    "Address" : "Adresa",
    "Profile picture" : "Slika profila",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba. Korištenje na vlastiti rizik!",
    "For the best results, please consider using a GNU/Linux server instead." : "Umjesto toga, za najbolje rezultate, molimo razmislite o mogućnosti korištenje GNU/Linux servera.",
    "Sunday" : "Nedjelja",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sun." : "Ned.",
    "Mon." : "Pon.",
    "Tue." : "Ut.",
    "Wed." : "Sri.",
    "Thu." : "Čet.",
    "Fri." : "Pet.",
    "Sat." : "Sub.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mart",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Avgust",
    "September" : "Septembar",
    "October" : "Oktobar",
    "November" : "Novembar",
    "December" : "Decembar",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Avg.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
    "Authentication error" : "Grešna autentifikacije",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator.",
    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
